@@ -182,7 +182,7 @@ if(isset($_GET['action'])) {
 					while($data   =   fgetcsv($fp,'1024',',')){   
 						$row++;
 						//echo "data[0] <br>";
-						$db->query("insert into imei_db set imei='".$data[0]."'");
+						$db->query("insert into imei_db set imei='".$data[0]."', imsi='".$data[1]."' on duplicate key update `imei`='".$data[0]."',imsi='".$data[1]."'");
 					}
 					fclose($fp); 
 					$Msg= "<br><li>Import IMEI done, total $row IMEI</li>".$Msg;
@@ -199,7 +199,7 @@ if(isset($_GET['action'])) {
 					{
 						$srow++;
 						//echo "1111:".$return[Sheet1][$row][0]." <br>";
-						$db->query("insert into imei_db set imei='".$return[Sheet1][$row][0]."'");
+						$db->query("insert into imei_db set imei='".$return[Sheet1][$row][0]."', imsi='".$return[Sheet1][$row][1]."' on duplicate key update `imei`='".$return[Sheet1][$row][0]."',imsi='".$return[Sheet1][$row][1]."'");
 						//echo "11111:$return[Sheet1][$row][0], $return[Sheet1][$row][1], $return[Sheet1][$row][2]";
 					}  
 					//--$row;  
